@@ -14,6 +14,7 @@ from sanic_ext.extensions.base import Extension
 from sanic_ext.extensions.http.extension import HTTPExtension
 from sanic_ext.extensions.injection.extension import InjectionExtension
 from sanic_ext.extensions.injection.registry import InjectionRegistry
+from sanic_ext.extensions.openapi.builders import SpecificationBuilder
 from sanic_ext.extensions.openapi.extension import OpenAPIExtension
 from sanic_ext.utils.string import camel_to_snake
 
@@ -42,7 +43,7 @@ class Extend:
             )
 
         sanic_version = tuple(
-            map(int, __version__.strip(ascii_lowercase).split("."))
+            map(int, __version__.strip(ascii_lowercase).split(".", 3)[:3])
         )
 
         if MIN_SUPPORT > sanic_version:
@@ -53,7 +54,8 @@ class Extend:
             )
 
         self.app = app
-        self.extensions = []
+        self._openapi: Optional[SpecificationBuilder] = None
+        self.extensions: List[Extension] = []
         self._injection_registry: Optional[InjectionRegistry] = None
         app._ext = self
         app.ctx._dependencies = SimpleNamespace()
@@ -71,10 +73,15 @@ class Extend:
                     HTTPExtension,
                 ]
             )
+
+        started = set()
         for extclass in extensions[::-1]:
+            if extclass in started:
+                continue
             extension = extclass(app, self.config)
             extension._startup(self)
             self.extensions.append(extension)
+            started.add(extclass)
 
     def _display(self):
         init_logs = ["Sanic Extensions:"]
@@ -113,3 +120,10 @@ class Extend:
             return obj
 
         self.add_dependency(obj.__class__, getter)
+
+    @property
+    def openapi(self) -> SpecificationBuilder:
+        if not self._openapi:
+            self._openapi = SpecificationBuilder()
+
+        return self._openapi
